==> deepin-manual_6.5.25.tar.xz: BUILD/translations/deepin-manual_fr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" sourcelanguage="en_US" language="fr">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="322"/>
        <source>Learn Basic Operations</source>
        <translation>Apprenez les opérations de base</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="324"/>
        <source>Common Application Libraries</source>
        <translation>Les bibliothèques d&apos;application classiques</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="326"/>
        <source>Desktop Environment</source>
        <translation>Environnement de bureau </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="163"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="249"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Rechercher &quot;%1&quot; dans tout le texte</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="301"/>
        <source>The content was updated</source>
        <translation>Le contenu a été mis à jour</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="624"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="627"/>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="836"/>
        <source>Copy</source>
        <translation>Copie</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="21"/>
        <source>Quick Start</source>
        <translation>Démarrage rapide</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="22"/>
        <source>Video Guide</source>
        <translation>Guide vidéo</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="23"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="24"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Home</source>
        <translation>Accueil</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>  result</source>
        <translation>résultat</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>  results</source>
        <translation>résultats</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>Click to view </source>
        <translation>Cliquez pour voir</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>View all</source>
        <translation>Tout voir</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>App Store</source>
        <translation>App Store</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="105"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="106"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Le manuel est conçu pour aider les utilisateurs à utiliser le système d&apos;exploitation et ses applications, en fournissant des instructions spécifiques et des descriptions de fonctions.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="765"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="780"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>

==> deepin-manual_6.5.35.tar.xz: BUILD/translations/deepin-manual_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr" sourcelanguage="en_US">
<context>
    <name>ManualProxy</name>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="363"/>
        <source>Learn Basic Operations</source>
        <translation>Apprenez les opérations de base</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="366"/>
        <source>Common Application Libraries</source>
        <translation>Les bibliothèques d&apos;application classiques</translation>
    </message>
    <message>
        <location filename="../src/view/manual_proxy.cpp" line="369"/>
        <source>Desktop Environment</source>
        <translation>Environnement de bureau </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/view/widget/search_completion_window.cpp" line="197"/>
        <location filename="../src/view/widget/search_completion_window.cpp" line="291"/>
        <source>Search for &quot;%1&quot; in the full text</source>
        <translation>Rechercher &quot;%1&quot; dans tout le texte</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="363"/>
        <source>The content was updated</source>
        <translation>Le contenu a été mis à jour</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="767"/>
        <source>Search</source>
        <translation>Rechercher</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="35"/>
        <location filename="../src/view/web_window.cpp" line="771"/>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="1038"/>
        <source>Copy</source>
        <translation>Copie</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="25"/>
        <source>Quick Start</source>
        <translation>Démarrage rapide</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="26"/>
        <source>Video Guide</source>
        <translation>Guide vidéo</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="27"/>
        <source>System</source>
        <translation>Système</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="28"/>
        <source>Applications</source>
        <translation>Applications</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="29"/>
        <source>No search results</source>
        <translation>Aucun résultat trouvé</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="30"/>
        <source>Home</source>
        <translation>Accueil</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="31"/>
        <source>  result</source>
        <translation>résultat</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="32"/>
        <source>  results</source>
        <translation>résultats</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="33"/>
        <source>Click to view </source>
        <translation>Cliquez pour voir</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="34"/>
        <source>View all</source>
        <translation>Tout voir</translation>
    </message>
    <message>
        <location filename="../src/view/i18n_proxy.cpp" line="36"/>
        <source>App Store</source>
        <translation>App Store</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="136"/>
        <source>Manual</source>
        <translation>Manuel</translation>
    </message>
    <message>
        <location filename="../src/app/dman.cpp" line="137"/>
        <source>Manual is designed to help users learn the operating system and its applications, providing specific instructions and function descriptions.</source>
        <translation>Le manuel est conçu pour aider les utilisateurs à utiliser le système d&apos;exploitation et ses applications, en fournissant des instructions spécifiques et des descriptions de fonctions.</translation>
    </message>
</context>
<context>
    <name>WebWindow</name>
    <message>
        <location filename="../src/view/web_window.cpp" line="952"/>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <location filename="../src/view/web_window.cpp" line="969"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
</context>
</TS>
